pub type AllPalletsWithoutSystem = (PalletWithSpecificRuntimeCall,);Expand description
All pallets included in the runtime as a nested tuple of types. Excludes the System pezpallet.
pub type AllPalletsWithoutSystem = (PalletWithSpecificRuntimeCall,);All pallets included in the runtime as a nested tuple of types. Excludes the System pezpallet.